Value

Enum Value 

pub enum Value {
    Null,
    Bool(bool),
    Int(i64),
    Float(f64),
    String(String),
    Binary(Binary),
    Timestamp(Timestamp),
    List(Vec<Value>),
    Map(BTreeMap<String, Value>),
}
Represents a valid JASN value.

Variants



Null

Null value.



Bool(bool)

Boolean value (true or false).



Int(i64)

64-bit signed integer.



Float(f64)

64-bit floating-point number.



String(String)

UTF-8 string.



Binary(Binary)

Binary data (byte array).



Timestamp(Timestamp)

Timestamp with timezone (ISO8601/RFC3339 compatible).



List(Vec<Value>)

Ordered list of values.



Map(BTreeMap<String, Value>)

Map of string keys to values.

Implementations

Source

impl Value

pub fn is_null(&self) -> bool

Returns true if the value is Self::Null.

pub fn is_bool(&self) -> bool

Returns true if the value is Self::Bool.

pub fn is_int(&self) -> bool

Returns true if the value is Self::Int.

pub fn is_float(&self) -> bool

Returns true if the value is Self::Float.

pub fn is_string(&self) -> bool

Returns true if the value is Self::String.

pub fn is_binary(&self) -> bool

Returns true if the value is Self::Binary.

pub fn is_timestamp(&self) -> bool

Returns true if the value is Self::Timestamp.

pub fn is_list(&self) -> bool

Returns true if the value is Self::List.

pub fn is_map(&self) -> bool

Returns true if the value is Self::Map.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value if this is a Self::Bool, otherwise None.

pub fn as_int(&self) -> Option<i64>

Returns the i64 value if this is a Self::Int, otherwise None.

pub fn as_float(&self) -> Option<f64>

Returns the f64 value if this is a Self::Float, otherwise None.

pub fn as_string(&self) -> Option<&str>

Returns the str if this is a Self::String, otherwise None.

pub fn as_binary(&self) -> Option<&Binary>

Returns the Binary if this is a Self::Binary, otherwise None.

pub fn as_timestamp(&self) -> Option<&Timestamp>

Returns the Timestamp value if this is a Self::Timestamp, otherwise None.

pub fn as_list(&self) -> Option<&[Value]>

Returns the list of values if this is a Self::List, otherwise None.

pub fn as_map(&self) -> Option<&BTreeMap<String, Value>>

Returns the map of key-value pairs if this is a Self::Map, otherwise None.

pub fn as_list_mut(&mut self) -> Option<&mut Vec<Value>>

Returns a mutable reference to the list of values if this is a Self::List, otherwise None.

pub fn as_map_mut(&mut self) -> Option<&mut BTreeMap<String, Value>>

Returns a mutable reference to the map of key-value pairs if this is a Self::Map, otherwise None.

pub fn take(&mut self) -> Value

Takes the value, leaving Self::Null in its place.